@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 import pytest
 
 from openpyxl.xml.functions import fromstring, tostring
@@ -46,11 +46,12 @@ def LegendEntry():
 class TestLegendEntry:
 
     def test_ctor(self, LegendEntry):
-        legend = LegendEntry()
+        legend = LegendEntry(idx=0, delete=True)
         xml = tostring(legend.to_tree())
         expected = """
         <legendEntry>
-          <idx val="0"></idx>
+          <idx val="0" />
+          <delete val= "1" />
         </legendEntry>
         """
         diff = compare_xml(xml, expected)
