@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 import re
 import warnings
@@ -25,7 +25,7 @@ def avoid_duplicate_name(names, value):
     match = [n for n in names if n.lower() == value.lower()]
     if match:
         names = u",".join(names)
-        sheet_title_regex = re.compile("(?P<title>%s)(?P<count>\d*),?" % re.escape(value), re.I)
+        sheet_title_regex = re.compile(r"(?P<title>%s)(?P<count>\d*),?" % re.escape(value), re.I)
         matches = sheet_title_regex.findall(names)
         if matches:
             # use name, but append with the next highest integer
@@ -77,6 +77,9 @@ class _WorkbookChild(object):
         Limited to 31 characters, no special characters.
         Duplicate titles will be incremented numerically
         """
+        if not self.__parent:
+            return
+
         if not value:
             raise ValueError("Title must have at least one character")
 
